@@ -1,5 +1,5 @@
 #
-# $Id: Split.pm,v 0.21 2003/12/30 14:12:32 st.schubiger Exp $
+# $Id: Split.pm,v 0.22 2003/12/30 15:03:39 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -36,7 +36,7 @@ our (# external refs
         $suffix,
     );
 
-our $VERSION = 0.21;
+our $VERSION = 0.22;
 
 =head1 NAME
 
@@ -294,7 +294,7 @@ sub _suffix_sum_up {
 #
 
 sub _dir_read {
-    my ($self, $dir_ref, $items_ref) = @_;
+    shift; my ($dir_ref, $items_ref) = @_;
 
     opendir D, $$dir_ref or
       croak qq~Could not open dir $$dir_ref for read-access: $!~;
@@ -312,7 +312,7 @@ sub _dir_read {
 
 sub _move_files {
     my $ret_f_moved;
-    for (; @$files_ref; $$suffix++) {
+    for (; @$files_ref; $$suffix_ref++) {
         # create subdir
         my $path = File::Spec->catfile($$target_dir_ref,
           "$$ident_ref$$sep_ref$$suffix_ref");
